@@ -49,7 +49,6 @@ QString charToNumber(QChar c)
         return c;
 }
 
-
 PeerID::PeerID()
 {
     memcpy(id, bt::PeerIDPrefix().toLatin1().constData(), 10);
@@ -58,7 +57,7 @@ PeerID::PeerID()
     client_name = identifyClient();
 }
 
-PeerID::PeerID(const char* pid)
+PeerID::PeerID(const char *pid)
 {
     if (pid)
         memcpy(id, pid, 20);
@@ -67,25 +66,24 @@ PeerID::PeerID(const char* pid)
     client_name = identifyClient();
 }
 
-PeerID::PeerID(const PeerID & pid)
+PeerID::PeerID(const PeerID &pid)
 {
     memcpy(id, pid.id, 20);
     client_name = pid.client_name;
 }
 
 PeerID::~PeerID()
-{}
+{
+}
 
-
-
-PeerID & PeerID::operator = (const PeerID & pid)
+PeerID &PeerID::operator=(const PeerID &pid)
 {
     memcpy(id, pid.id, 20);
     client_name = pid.client_name;
     return *this;
 }
 
-bool operator == (const PeerID & a, const PeerID & b)
+bool operator==(const PeerID &a, const PeerID &b)
 {
     for (int i = 0; i < 20; i++)
         if (a.id[i] != b.id[i])
@@ -94,12 +92,12 @@ bool operator == (const PeerID & a, const PeerID & b)
     return true;
 }
 
-bool operator != (const PeerID & a, const PeerID & b)
+bool operator!=(const PeerID &a, const PeerID &b)
 {
-    return ! operator == (a, b);
+    return !operator==(a, b);
 }
 
-bool operator < (const PeerID & a, const PeerID & b)
+bool operator<(const PeerID &a, const PeerID &b)
 {
     for (int i = 0; i < 20; i++)
         if (a.id[i] < b.id[i])
@@ -110,7 +108,8 @@ bool operator < (const PeerID & a, const PeerID & b)
 
 QString PeerID::toString() const
 {
-    QString r; r.reserve(20);
+    QString r;
+    r.reserve(20);
     for (int i = 0; i < 20; i++)
         r += id[i] == 0 ? ' ' : id[i];
     return r;
@@ -129,7 +128,7 @@ QString PeerID::identifyClient() const
 
     if (first) {
         // Keep things a bit alphabetic to make it easier add new ones
-        //AZUREUS STYLE
+        // AZUREUS STYLE
         Map[QStringLiteral("7T")] = QStringLiteral("aTorrent");
         Map[QStringLiteral("AB")] = QStringLiteral("AnyEvent::BitTorrent");
         Map[QStringLiteral("AG")] = QStringLiteral("Ares");
@@ -231,7 +230,7 @@ QString PeerID::identifyClient() const
         Map[QStringLiteral("XX")] = QStringLiteral("Xtorrent");
         Map[QStringLiteral("ZT")] = QStringLiteral("Zip Torrent");
 
-        //SHADOWS STYLE
+        // SHADOWS STYLE
         Map[QStringLiteral("A")] = QStringLiteral("ABC");
         Map[QStringLiteral("O")] = QStringLiteral("Osprey Permaseed");
         Map[QStringLiteral("Q")] = QStringLiteral("BTQueue");
@@ -239,7 +238,7 @@ QString PeerID::identifyClient() const
         Map[QStringLiteral("S")] = QStringLiteral("Shadow's");
         Map[QStringLiteral("T")] = QStringLiteral("BitTornado");
         Map[QStringLiteral("U")] = QStringLiteral("UPnP NAT BitTorrent");
-        //OTHER
+        // OTHER
         Map[QStringLiteral("Plus")] = QStringLiteral("Plus! II");
         Map[QStringLiteral("OP")] = QStringLiteral("Opera");
         Map[QStringLiteral("BOW")] = QStringLiteral("Bits on Wheels");
@@ -258,9 +257,7 @@ QString PeerID::identifyClient() const
     }
 
     QString name;
-    if (peer_id.at(0) == '-' &&
-        peer_id.at(1).isLetter() &&
-        peer_id.at(2).isLetter()) { //AZ style
+    if (peer_id.at(0) == '-' && peer_id.at(1).isLetter() && peer_id.at(2).isLetter()) { // AZ style
         QString ID(peer_id.mid(1, 2));
         if (ID == QLatin1String("ML")) {
             name = Map[ID];
@@ -269,21 +266,16 @@ QString PeerID::identifyClient() const
                 name += ' ' + peer_id.mid(3, dash_pos - 3);
         } else if (Map.contains(ID)) {
             if (peer_id.at(9) == '-') {
-                name = Map[ID] + ' ' + charToNumber(peer_id.at(3)) + charToNumber(peer_id.at(4))
-                        + '.' + charToNumber(peer_id.at(5)) + charToNumber(peer_id.at(6))
-                        + '.' + charToNumber(peer_id.at(7)) + charToNumber(peer_id.at(8));
+                name = Map[ID] + ' ' + charToNumber(peer_id.at(3)) + charToNumber(peer_id.at(4)) + '.' + charToNumber(peer_id.at(5))
+                    + charToNumber(peer_id.at(6)) + '.' + charToNumber(peer_id.at(7)) + charToNumber(peer_id.at(8));
             } else {
-                name = Map[ID] + ' ' + charToNumber(peer_id.at(3)) + '.' + charToNumber(peer_id.at(4)) + '.'
-                        + charToNumber(peer_id.at(5));
+                name = Map[ID] + ' ' + charToNumber(peer_id.at(3)) + '.' + charToNumber(peer_id.at(4)) + '.' + charToNumber(peer_id.at(5));
             }
         }
-    } else if (peer_id.at(0).isLetter() &&
-               peer_id.at(1).isDigit() &&
-               peer_id.at(2).isDigit()) { //Shadow's style
+    } else if (peer_id.at(0).isLetter() && peer_id.at(1).isDigit() && peer_id.at(2).isDigit()) { // Shadow's style
         QString ID = QString(peer_id.at(0));
         if (Map.contains(ID))
-            name = Map[ID] + ' ' + peer_id.at(1) + '.' +
-                   peer_id.at(2) + '.' + peer_id.at(3);
+            name = Map[ID] + ' ' + peer_id.at(1) + '.' + peer_id.at(2) + '.' + peer_id.at(3);
     } else if (peer_id.at(0) == 'M' && peer_id.at(2) == '-' && (peer_id.at(4) == '-' || peer_id.at(5) == '-')) {
         name = Map[QStringLiteral("M")] + ' ' + peer_id.at(1) + '.' + peer_id.at(3);
         if (peer_id.at(4) == '-')
@@ -303,11 +295,9 @@ QString PeerID::identifyClient() const
     } else if (peer_id.startsWith(QLatin1String("XBT"))) {
         name = Map[QStringLiteral("XBT")] + ' ' + peer_id.at(3) + '.' + peer_id.at(4) + '.' + peer_id.at(5);
     } else if (peer_id.startsWith(QLatin1String("SP"))) {
-        name = Map[QStringLiteral("SP")] + ' ' + peer_id.at(2) + '.' + peer_id.at(3) + '.'
-               + peer_id.at(4) + '.' + peer_id.at(5);
+        name = Map[QStringLiteral("SP")] + ' ' + peer_id.at(2) + '.' + peer_id.at(3) + '.' + peer_id.at(4) + '.' + peer_id.at(5);
     } else if (peer_id.startsWith(QLatin1String("FG"))) {
-        name = Map[QStringLiteral("FG")] + ' ' + peer_id.at(2) + '.' + peer_id.at(3) + '.'
-               + peer_id.at(4) + '.' + peer_id.at(5);
+        name = Map[QStringLiteral("FG")] + ' ' + peer_id.at(2) + '.' + peer_id.at(3) + '.' + peer_id.at(4) + '.' + peer_id.at(5);
     } else if (peer_id.midRef(2, 2) == QLatin1String("RS")) {
         name = Map[QStringLiteral("RS")];
     } else if (peer_id.startsWith(QLatin1String("Q1"))) {
@@ -317,8 +307,7 @@ QString PeerID::identifyClient() const
     } else if (peer_id.startsWith(QLatin1String("QVOD"))) {
         name = Map[QStringLiteral("QVOD")];
     } else if (peer_id.startsWith(QLatin1String("TIX"))) {
-        name = Map[QStringLiteral("TIX")] + ' ' + peer_id.at(3) + peer_id.at(4) + '.'
-               + peer_id.at(5) + peer_id.at(6);
+        name = Map[QStringLiteral("TIX")] + ' ' + peer_id.at(3) + peer_id.at(4) + '.' + peer_id.at(5) + peer_id.at(6);
     }
     if (name.isEmpty()) {
         name = i18n("Unknown client");
