@@ -24,9 +24,9 @@
 #include <QTextStream>
 #include <QUrl>
 
-#include <unistd.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
+#include <sys/socket.h>
+#include <unistd.h>
 #ifndef Q_WS_WIN
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
@@ -34,21 +34,15 @@
 #include <arpa/inet.h>
 #include <util/log.h>
 
-
 namespace bt
 {
-static bool UrlCompare(const QUrl &a, const QUrl & b)
+static bool UrlCompare(const QUrl &a, const QUrl &b)
 {
     if (a == b)
         return true;
 
-    return
-        a.scheme() == b.scheme() &&
-        a.host() == b.host() &&
-        a.password() == b.password() &&
-        a.port(80) == b.port(80) &&
-        a.path() == b.path() &&
-        a.query() == b.query(); //TODO check if ported correctly
+    return a.scheme() == b.scheme() && a.host() == b.host() && a.password() == b.password() && a.port(80) == b.port(80) && a.path() == b.path()
+        && a.query() == b.query(); // TODO check if ported correctly
 }
 
 class UPnPMCastSocket::UPnPMCastSocketPrivate
@@ -57,18 +51,19 @@ public:
     UPnPMCastSocketPrivate(bool verbose);
     ~UPnPMCastSocketPrivate();
 
-    UPnPRouter* parseResponse(const QByteArray & arr);
+    UPnPRouter *parseResponse(const QByteArray &arr);
     void joinUPnPMCastGroup(int fd);
     void leaveUPnPMCastGroup(int fd);
-    void onXmlFileDownloaded(UPnPRouter* r, bool success);
-    UPnPRouter* findDevice(const QUrl &location);
+    void onXmlFileDownloaded(UPnPRouter *r, bool success);
+    UPnPRouter *findDevice(const QUrl &location);
 
-    QSet<UPnPRouter*> routers;
-    QSet<UPnPRouter*> pending_routers; // routers which we are downloading the XML file from
+    QSet<UPnPRouter *> routers;
+    QSet<UPnPRouter *> pending_routers; // routers which we are downloading the XML file from
     bool verbose;
 };
 
-UPnPMCastSocket::UPnPMCastSocket(bool verbose) : d(new UPnPMCastSocketPrivate(verbose))
+UPnPMCastSocket::UPnPMCastSocket(bool verbose)
+    : d(new UPnPMCastSocketPrivate(verbose))
 {
     QObject::connect(this, &UPnPMCastSocket::readyRead, this, &UPnPMCastSocket::onReadyRead);
     QObject::connect(this, &UPnPMCastSocket::error, this, &UPnPMCastSocket::error);
@@ -83,7 +78,6 @@ UPnPMCastSocket::UPnPMCastSocket(bool verbose) : d(new UPnPMCastSocketPrivate(ve
     d->joinUPnPMCastGroup(socketDescriptor());
 }
 
-
 UPnPMCastSocket::~UPnPMCastSocket()
 {
     d->leaveUPnPMCastGroup(socketDescriptor());
@@ -94,21 +88,22 @@ void UPnPMCastSocket::discover()
 {
     Out(SYS_PNP | LOG_NOTICE) << "Trying to find UPnP devices on the local network" << endl;
 
-
     // send a HTTP M-SEARCH message to 239.255.255.250:1900
-    const char* upnp_data = "M-SEARCH * HTTP/1.1\r\n"
-                            "HOST: 239.255.255.250:1900\r\n"
-                            "ST:urn:schemas-upnp-org:device:InternetGatewayDevice:1\r\n"
-                            "MAN:\"ssdp:discover\"\r\n"
-                            "MX:3\r\n"
-                            "\r\n\0";
+    const char *upnp_data =
+        "M-SEARCH * HTTP/1.1\r\n"
+        "HOST: 239.255.255.250:1900\r\n"
+        "ST:urn:schemas-upnp-org:device:InternetGatewayDevice:1\r\n"
+        "MAN:\"ssdp:discover\"\r\n"
+        "MX:3\r\n"
+        "\r\n\0";
 
-    const char* tr64_data = "M-SEARCH * HTTP/1.1\r\n"
-                            "HOST: 239.255.255.250:1900\r\n"
-                            "ST:urn:dslforum-org:device:InternetGatewayDevice:1\r\n"
-                            "MAN:\"ssdp:discover\"\r\n"
-                            "MX:3\r\n"
-                            "\r\n\0";
+    const char *tr64_data =
+        "M-SEARCH * HTTP/1.1\r\n"
+        "HOST: 239.255.255.250:1900\r\n"
+        "ST:urn:dslforum-org:device:InternetGatewayDevice:1\r\n"
+        "MAN:\"ssdp:discover\"\r\n"
+        "MX:3\r\n"
+        "\r\n\0";
 
     if (d->verbose) {
         Out(SYS_PNP | LOG_NOTICE) << "Sending : " << endl;
@@ -122,7 +117,7 @@ void UPnPMCastSocket::discover()
     writeDatagram(tr64_data, strlen(tr64_data), QHostAddress("239.255.255.250"), 1900);
 }
 
-void UPnPMCastSocket::onXmlFileDownloaded(UPnPRouter* r, bool success)
+void UPnPMCastSocket::onXmlFileDownloaded(UPnPRouter *r, bool success)
 {
     d->pending_routers.remove(r);
     if (!success) {
@@ -163,7 +158,7 @@ void UPnPMCastSocket::onReadyRead()
     }
 
     // try to make a router of it
-    UPnPRouter* r = d->parseResponse(data);
+    UPnPRouter *r = d->parseResponse(data);
     if (r) {
         QObject::connect(r, &UPnPRouter::xmlFileDownloaded, this, &UPnPMCastSocket::onXmlFileDownloaded);
 
@@ -178,7 +173,7 @@ void UPnPMCastSocket::error(QAbstractSocket::SocketError)
     Out(SYS_PNP | LOG_IMPORTANT) << "UPnPMCastSocket Error : " << errorString() << endl;
 }
 
-void UPnPMCastSocket::saveRouters(const QString & file)
+void UPnPMCastSocket::saveRouters(const QString &file)
 {
     QFile fptr(file);
     if (!fptr.open(QIODevice::WriteOnly)) {
@@ -189,13 +184,13 @@ void UPnPMCastSocket::saveRouters(const QString & file)
     // file format is simple : 2 lines per router,
     // one containing the server, the other the location
     QTextStream fout(&fptr);
-    for (UPnPRouter* r : qAsConst(d->routers)) {
+    for (UPnPRouter *r : qAsConst(d->routers)) {
         fout << r->getServer() << Qt::endl;
         fout << r->getLocation().toString() << Qt::endl;
     }
 }
 
-void UPnPMCastSocket::loadRouters(const QString & file)
+void UPnPMCastSocket::loadRouters(const QString &file)
 {
     QFile fptr(file);
     if (!fptr.open(QIODevice::ReadOnly)) {
@@ -212,7 +207,7 @@ void UPnPMCastSocket::loadRouters(const QString & file)
         server = fin.readLine();
         location = fin.readLine();
 
-        UPnPRouter* r = new UPnPRouter(server, QUrl(location));
+        UPnPRouter *r = new UPnPRouter(server, QUrl(location));
         // download it's xml file
         QObject::connect(r, &UPnPRouter::xmlFileDownloaded, this, &UPnPMCastSocket::onXmlFileDownloaded);
         r->downloadXMLFile();
@@ -225,7 +220,7 @@ Uint32 UPnPMCastSocket::getNumDevicesDiscovered() const
     return d->routers.count();
 }
 
-UPnPRouter* UPnPMCastSocket::findDevice(const QString & name)
+UPnPRouter *UPnPMCastSocket::findDevice(const QString &name)
 {
     QUrl location(name);
     return d->findDevice(location);
@@ -238,7 +233,8 @@ void UPnPMCastSocket::setVerbose(bool v)
 
 /////////////////////////////////////////////////////////////
 
-UPnPMCastSocket::UPnPMCastSocketPrivate::UPnPMCastSocketPrivate(bool verbose) : verbose(verbose)
+UPnPMCastSocket::UPnPMCastSocketPrivate::UPnPMCastSocketPrivate(bool verbose)
+    : verbose(verbose)
 {
 }
 
@@ -284,7 +280,7 @@ void UPnPMCastSocket::UPnPMCastSocketPrivate::leaveUPnPMCastGroup(int fd)
     }
 }
 
-UPnPRouter* UPnPMCastSocket::UPnPMCastSocketPrivate::parseResponse(const QByteArray & arr)
+UPnPRouter *UPnPMCastSocket::UPnPMCastSocketPrivate::parseResponse(const QByteArray &arr)
 {
     const QString response = QString::fromLatin1(arr);
     QVector<QStringRef> lines = response.splitRef("\r\n");
@@ -323,14 +319,13 @@ UPnPRouter* UPnPMCastSocket::UPnPMCastSocketPrivate::parseResponse(const QByteAr
     for (int i = 1; i < lines.count(); i++) {
         line = lines[i];
         if (line.startsWith(QLatin1String("location"), Qt::CaseInsensitive)) {
-            location = QUrl(line.mid(line.indexOf(':') + 1).trimmed().toString()); //TODO fromLocalFile()?
+            location = QUrl(line.mid(line.indexOf(':') + 1).trimmed().toString()); // TODO fromLocalFile()?
             if (!location.isValid())
                 return 0;
         } else if (line.startsWith(QLatin1String("server"), Qt::CaseInsensitive)) {
             server = line.mid(line.indexOf(':') + 1).trimmed().toString();
             if (server.length() == 0)
                 return 0;
-
         }
     }
 
@@ -343,9 +338,9 @@ UPnPRouter* UPnPMCastSocket::UPnPMCastSocketPrivate::parseResponse(const QByteAr
     }
 }
 
-UPnPRouter* UPnPMCastSocket::UPnPMCastSocketPrivate::findDevice(const QUrl &location)
+UPnPRouter *UPnPMCastSocket::UPnPMCastSocketPrivate::findDevice(const QUrl &location)
 {
-    for (UPnPRouter* r : qAsConst(routers)) {
+    for (UPnPRouter *r : qAsConst(routers)) {
         if (UrlCompare(r->getLocation(), location))
             return r;
     }
@@ -353,7 +348,4 @@ UPnPRouter* UPnPMCastSocket::UPnPMCastSocketPrivate::findDevice(const QUrl &loca
     return 0;
 }
 
-
 }
-
-
